@@ -1,47 +1,35 @@
-/* This file is part of the KDE project
- *
- * Copyright (C) 2004 Jakub Stachowski <qbast@go2.pl>
- * Copyright (C) 2018 Harald Sitter <sitter@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE project
+
+    SPDX-FileCopyrightText: 2004 Jakub Stachowski <qbast@go2.pl>
+    SPDX-FileCopyrightText: 2018 Harald Sitter <sitter@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "avahi-domainbrowser_p.h"
-#include <QSet>
-#include <QFile>
-#include <QIODevice>
-#include <QStandardPaths>
-#include <avahi-common/defs.h>
+#include "avahi_domainbrowser_interface.h"
 #include "avahi_server_interface.h"
 #include "domainbrowser.h"
-#include "avahi_domainbrowser_interface.h"
+#include <QFile>
+#include <QIODevice>
+#include <QSet>
+#include <QStandardPaths>
+#include <avahi-common/defs.h>
 
 namespace KDNSSD
 {
-
-DomainBrowser::DomainBrowser(DomainType type, QObject *parent) : QObject(parent), d(new DomainBrowserPrivate(type, this))
-{}
-
-DomainBrowser::~DomainBrowser()
+DomainBrowser::DomainBrowser(DomainType type, QObject *parent)
+    : QObject(parent)
+    , d(new DomainBrowserPrivate(type, this))
 {
-    delete d;
 }
 
+DomainBrowser::~DomainBrowser() = default;
+
 void DomainBrowser::startBrowse()
 {
+    Q_D(DomainBrowser);
     if (d->m_started) {
         return;
     }
@@ -60,32 +48,25 @@ void DomainBrowser::startBrowse()
     // This uses a fancy trick whereby using QDBusMessage as last argument will
     // give us the correct signal argument types as well as the underlying
     // message so that we may check the message path.
+    QDBusConnection::systemBus().connect("org.freedesktop.Avahi",
+                                         "",
+                                         "org.freedesktop.Avahi.DomainBrowser",
+                                         "ItemNew",
+                                         d,
+                                         SLOT(gotGlobalItemNew(int, int, QString, uint, QDBusMessage)));
+    QDBusConnection::systemBus().connect("org.freedesktop.Avahi",
+                                         "",
+                                         "org.freedesktop.Avahi.DomainBrowser",
+                                         "ItemRemove",
+                                         d,
+                                         SLOT(gotGlobalItemRemove(int, int, QString, uint, QDBusMessage)));
     QDBusConnection::systemBus()
-            .connect("org.freedesktop.Avahi",
-                     "",
-                     "org.freedesktop.Avahi.DomainBrowser",
-                     "ItemNew",
-                     d,
-                     SLOT(gotGlobalItemNew(int,int,QString,uint,QDBusMessage)));
-    QDBusConnection::systemBus()
-            .connect("org.freedesktop.Avahi",
-                     "",
-                     "org.freedesktop.Avahi.DomainBrowser",
-                     "ItemRemove",
-                     d,
-                     SLOT(gotGlobalItemRemove(int,int,QString,uint,QDBusMessage)));
-    QDBusConnection::systemBus()
-            .connect("org.freedesktop.Avahi",
-                     "",
-                     "org.freedesktop.Avahi.DomainBrowser",
-                     "AllForNow",
-                     d,
-                     SLOT(gotGlobalAllForNow(QDBusMessage)));
+        .connect("org.freedesktop.Avahi", "", "org.freedesktop.Avahi.DomainBrowser", "AllForNow", d, SLOT(gotGlobalAllForNow(QDBusMessage)));
     d->m_dbusObjectPath.clear();
 
     org::freedesktop::Avahi::Server s(QStringLiteral("org.freedesktop.Avahi"), QStringLiteral("/"), QDBusConnection::systemBus());
-    QDBusReply<QDBusObjectPath> rep = s.DomainBrowserNew(-1, -1, QString(), (d->m_type == Browsing) ?
-                                      AVAHI_DOMAIN_BROWSER_BROWSE : AVAHI_DOMAIN_BROWSER_REGISTER, 0);
+    QDBusReply<QDBusObjectPath> rep =
+        s.DomainBrowserNew(-1, -1, QString(), (d->m_type == Browsing) ? AVAHI_DOMAIN_BROWSER_BROWSE : AVAHI_DOMAIN_BROWSER_REGISTER, 0);
     if (!rep.isValid()) {
         return;
     }
@@ -93,20 +74,17 @@ void DomainBrowser::startBrowse()
     d->m_dbusObjectPath = rep.value().path();
 
     // This is held because we need to explicitly Free it!
-    d->m_browser = new org::freedesktop::Avahi::DomainBrowser(
-                s.service(),
-                d->m_dbusObjectPath,
-                s.connection());
+    d->m_browser = new org::freedesktop::Avahi::DomainBrowser(s.service(), d->m_dbusObjectPath, s.connection());
 
     if (d->m_type == Browsing) {
         QString domains_evar = QString::fromLocal8Bit(qgetenv("AVAHI_BROWSE_DOMAINS"));
         if (!domains_evar.isEmpty()) {
-            QStringList edomains = domains_evar.split(QLatin1Char(':'));
-            Q_FOREACH (const QString &s, edomains) {
+            const QStringList edomains = domains_evar.split(QLatin1Char(':'));
+            for (const QString &s : edomains) {
                 d->gotNewDomain(-1, -1, s, 0);
             }
         }
-        //FIXME: watch this file and restart browser if it changes
+        // FIXME: watch this file and restart browser if it changes
         QString confDir = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation);
         QFile domains_cfg(confDir + QStringLiteral("/avahi/browse-domains"));
         if (domains_cfg.open(QIODevice::ReadOnly | QIODevice::Text))
@@ -116,11 +94,7 @@ void DomainBrowser::startBrowse()
     }
 }
 
-void DomainBrowserPrivate::gotGlobalItemNew(int interface,
-                                            int protocol,
-                                            const QString &domain,
-                                            uint flags,
-                                            QDBusMessage msg)
+void DomainBrowserPrivate::gotGlobalItemNew(int interface, int protocol, const QString &domain, uint flags, QDBusMessage msg)
 {
     if (!isOurMsg(msg)) {
         return;
@@ -128,11 +102,7 @@ void DomainBrowserPrivate::gotGlobalItemNew(int interface,
     gotNewDomain(interface, protocol, domain, flags);
 }
 
-void DomainBrowserPrivate::gotGlobalItemRemove(int interface,
-                                               int protocol,
-                                               const QString &domain,
-                                               uint flags,
-                                               QDBusMessage msg)
+void DomainBrowserPrivate::gotGlobalItemRemove(int interface, int protocol, const QString &domain, uint flags, QDBusMessage msg)
 {
     if (!isOurMsg(msg)) {
         return;
@@ -154,7 +124,7 @@ void DomainBrowserPrivate::gotNewDomain(int, int, const QString &domain, uint)
         return;
     }
     m_domains += decoded;
-    emit m_parent->domainAdded(decoded);
+    Q_EMIT m_parent->domainAdded(decoded);
 }
 
 void DomainBrowserPrivate::gotRemoveDomain(int, int, const QString &domain, uint)
@@ -163,20 +133,22 @@ void DomainBrowserPrivate::gotRemoveDomain(int, int, const QString &domain, uint
     if (!m_domains.contains(decoded)) {
         return;
     }
-    emit m_parent->domainRemoved(decoded);
+    Q_EMIT m_parent->domainRemoved(decoded);
     m_domains.remove(decoded);
 }
 
 QStringList DomainBrowser::domains() const
 {
+    Q_D(const DomainBrowser);
     return d->m_domains.values();
 }
 
 bool DomainBrowser::isRunning() const
 {
+    Q_D(const DomainBrowser);
     return d->m_started;
 }
 
 }
-#include "moc_domainbrowser.cpp"
 #include "moc_avahi-domainbrowser_p.cpp"
+#include "moc_domainbrowser.cpp"
